[−][src]Enum unicode_types::balinese::Balinese
An enum to represent all characters in the Balinese block.
Variants
SignUluRicem\u{1b00}: 'ᬀ'
SignUluCandra\u{1b01}: 'ᬁ'
SignCecek\u{1b02}: 'ᬂ'
SignSurang\u{1b03}: 'ᬃ'
SignBisah\u{1b04}: 'ᬄ'
LetterAkara\u{1b05}: 'ᬅ'
LetterAkaraTedung\u{1b06}: 'ᬆ'
LetterIkara\u{1b07}: 'ᬇ'
LetterIkaraTedung\u{1b08}: 'ᬈ'
LetterUkara\u{1b09}: 'ᬉ'
LetterUkaraTedung\u{1b0a}: 'ᬊ'
LetterRaRepa\u{1b0b}: 'ᬋ'
LetterRaRepaTedung\u{1b0c}: 'ᬌ'
LetterLaLenga\u{1b0d}: 'ᬍ'
LetterLaLengaTedung\u{1b0e}: 'ᬎ'
LetterEkara\u{1b0f}: 'ᬏ'
LetterAikara\u{1b10}: 'ᬐ'
LetterOkara\u{1b11}: 'ᬑ'
LetterOkaraTedung\u{1b12}: 'ᬒ'
LetterKa\u{1b13}: 'ᬓ'
LetterKaMahaprana\u{1b14}: 'ᬔ'
LetterGa\u{1b15}: 'ᬕ'
LetterGaGora\u{1b16}: 'ᬖ'
LetterNga\u{1b17}: 'ᬗ'
LetterCa\u{1b18}: 'ᬘ'
LetterCaLaca\u{1b19}: 'ᬙ'
LetterJa\u{1b1a}: 'ᬚ'
LetterJaJera\u{1b1b}: 'ᬛ'
LetterNya\u{1b1c}: 'ᬜ'
LetterTaLatik\u{1b1d}: 'ᬝ'
LetterTaMurdaMahaprana\u{1b1e}: 'ᬞ'
LetterDaMurdaAlpaprana\u{1b1f}: 'ᬟ'
LetterDaMurdaMahaprana\u{1b20}: 'ᬠ'
LetterNaRambat\u{1b21}: 'ᬡ'
LetterTa\u{1b22}: 'ᬢ'
LetterTaTawa\u{1b23}: 'ᬣ'
LetterDa\u{1b24}: 'ᬤ'
LetterDaMadu\u{1b25}: 'ᬥ'
LetterNa\u{1b26}: 'ᬦ'
LetterPa\u{1b27}: 'ᬧ'
LetterPaKapal\u{1b28}: 'ᬨ'
LetterBa\u{1b29}: 'ᬩ'
LetterBaKembang\u{1b2a}: 'ᬪ'
LetterMa\u{1b2b}: 'ᬫ'
LetterYa\u{1b2c}: 'ᬬ'
LetterRa\u{1b2d}: 'ᬭ'
LetterLa\u{1b2e}: 'ᬮ'
LetterWa\u{1b2f}: 'ᬯ'
LetterSaSaga\u{1b30}: 'ᬰ'
LetterSaSapa\u{1b31}: 'ᬱ'
LetterSa\u{1b32}: 'ᬲ'
LetterHa\u{1b33}: 'ᬳ'
SignRerekan\u{1b34}: '᬴'
VowelSignTedung\u{1b35}: 'ᬵ'
VowelSignUlu\u{1b36}: 'ᬶ'
VowelSignUluSari\u{1b37}: 'ᬷ'
VowelSignSuku\u{1b38}: 'ᬸ'
VowelSignSukuIlut\u{1b39}: 'ᬹ'
VowelSignRaRepa\u{1b3a}: 'ᬺ'
VowelSignRaRepaTedung\u{1b3b}: 'ᬻ'
VowelSignLaLenga\u{1b3c}: 'ᬼ'
VowelSignLaLengaTedung\u{1b3d}: 'ᬽ'
VowelSignTaling\u{1b3e}: 'ᬾ'
VowelSignTalingRepa\u{1b3f}: 'ᬿ'
VowelSignTalingTedung\u{1b40}: 'ᭀ'
VowelSignTalingRepaTedung\u{1b41}: 'ᭁ'
VowelSignPepet\u{1b42}: 'ᭂ'
VowelSignPepetTedung\u{1b43}: 'ᭃ'
AdegAdeg\u{1b44}: '᭄'
LetterKafSasak\u{1b45}: 'ᭅ'
LetterKhotSasak\u{1b46}: 'ᭆ'
LetterTzirSasak\u{1b47}: 'ᭇ'
LetterEfSasak\u{1b48}: 'ᭈ'
LetterVeSasak\u{1b49}: 'ᭉ'
LetterZalSasak\u{1b4a}: 'ᭊ'
LetterAsyuraSasak\u{1b4b}: 'ᭋ'
DigitZero\u{1b50}: '᭐'
DigitOne\u{1b51}: '᭑'
DigitTwo\u{1b52}: '᭒'
DigitThree\u{1b53}: '᭓'
DigitFour\u{1b54}: '᭔'
DigitFive\u{1b55}: '᭕'
DigitSix\u{1b56}: '᭖'
DigitSeven\u{1b57}: '᭗'
DigitEight\u{1b58}: '᭘'
DigitNine\u{1b59}: '᭙'
Panti\u{1b5a}: '᭚'
Pamada\u{1b5b}: '᭛'
Windu\u{1b5c}: '᭜'
CarikPamungkah\u{1b5d}: '᭝'
CarikSiki\u{1b5e}: '᭞'
CarikPareren\u{1b5f}: '᭟'
Pameneng\u{1b60}: '᭠'
MusicalSymbolDong\u{1b61}: '᭡'
MusicalSymbolDeng\u{1b62}: '᭢'
MusicalSymbolDung\u{1b63}: '᭣'
MusicalSymbolDang\u{1b64}: '᭤'
MusicalSymbolDangSurang\u{1b65}: '᭥'
MusicalSymbolDing\u{1b66}: '᭦'
MusicalSymbolDaeng\u{1b67}: '᭧'
MusicalSymbolDeung\u{1b68}: '᭨'
MusicalSymbolDaing\u{1b69}: '᭩'
MusicalSymbolDangGede\u{1b6a}: '᭪'
MusicalSymbolCombiningTegeh\u{1b6b}: '᭫'
MusicalSymbolCombiningEndep\u{1b6c}: '᭬'
MusicalSymbolCombiningKempul\u{1b6d}: '᭭'
MusicalSymbolCombiningKempli\u{1b6e}: '᭮'
MusicalSymbolCombiningJegogan\u{1b6f}: '᭯'
MusicalSymbolCombiningKempulWithJegogan\u{1b70}: '᭰'
MusicalSymbolCombiningKempliWithJegogan\u{1b71}: '᭱'
MusicalSymbolCombiningBende\u{1b72}: '᭲'
MusicalSymbolCombiningGong\u{1b73}: '᭳'
MusicalSymbolRightDashHandOpenDug\u{1b74}: '᭴'
MusicalSymbolRightDashHandOpenDag\u{1b75}: '᭵'
MusicalSymbolRightDashHandClosedTuk\u{1b76}: '᭶'
MusicalSymbolRightDashHandClosedTak\u{1b77}: '᭷'
MusicalSymbolLeftDashHandOpenPang\u{1b78}: '᭸'
MusicalSymbolLeftDashHandOpenPung\u{1b79}: '᭹'
MusicalSymbolLeftDashHandClosedPlak\u{1b7a}: '᭺'
MusicalSymbolLeftDashHandClosedPluk\u{1b7b}: '᭻'
MusicalSymbolLeftDashHandOpenPing\u{1b7c}: '᭼'
Methods
impl Balinese[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case